package de.intevation.flys.importer;

import de.intevation.flys.model.Wst;
import de.intevation.flys.model.River;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import java.util.ArrayList;
import java.util.List;

public class ImportWst
{
    private static Logger log = Logger.getLogger(ImportWst.class);

    protected String description;

    protected Integer kind;

    protected List<ImportWstColumn> columns;

    protected Wst peer;

    public ImportWst() {
        kind = 0;
        columns = new ArrayList<ImportWstColumn>();
    }

    public ImportWst(String description) {
        this();
        this.description = description;
    }

    public String getDescription() {
        return description;
    }

    public Integer getKind() {
        return kind;
    }

    public void setKind(Integer kind) {
        this.kind = kind;
    }


    public void setDescription(String description) {
        this.description = description;
    }

    public void setNumberColumns(int numColumns) {
        for (int i = 0; i < numColumns; ++i) {
            columns.add(new ImportWstColumn(this, null, null, i));
        }
    }

    public int getNumberColumns() {
        return columns.size();
    }

    public ImportWstColumn getColumn(int index) {
        return columns.get(index);
    }

    public void storeDependencies(River river) {

        log.info("store '" + description + "'");
        Wst wst = getPeer(river);

        for (ImportWstColumn column: columns) {
            column.storeDependencies(river);
        }
    }

    public Wst getPeer(River river) {
        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();
            Query query = session.createQuery(
                "from Wst where " +
                "river=:river and description=:description and kind=:kind");
            query.setParameter("river",       river);
            query.setParameter("description", description);
            query.setParameter("kind",        kind);
            List<Wst> wsts = query.list();
            if (wsts.isEmpty()) {
                peer = new Wst(river, description, kind);
                session.save(peer);
            }
            else {
                peer = wsts.get(0);
            }

        }
        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
